IMAS Data Dictionary documentation Version |version|
====================================================

The IMAS Data Dictionary (DD) defines the standardized data structures used
for IMAS data. See :ref:`introduction` for more background about the Data
Dictionary and IMAS in general.

View the :ref:`reference` for a detailed reference of all IDSs, or use the
`search bar <?q=>`_ to look for specific IDSs or nodes. The :ref:`query tool`
can be used for more advanced search queries.

.. toctree::
   :maxdepth: 2
   :caption: Contents

   intro
   data_dictionary_glossary
   generated/changelog/git
   generated/changelog/ids


.. toctree::
   :caption: Advanced search

   qt

.. toctree::
   :maxdepth: 3
   :caption: Data dictionary reference
   :name: dd-index-reference-toc

   reference_ids
   reference_util
   reference_identifier


.. toctree::
   :maxdepth: 2
   :caption: GGD guide

   ggd_guide/doc
   ggd_guide/examples


.. toctree::
   :maxdepth: 2
   :caption: Developer documentation

   developer_docs


..
   Indices and tables
   ==================

   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`
